@@ -1,4 +1,4 @@
-from typing import Any, Callable, Dict, List, Optional, Union, cast
+from typing import Any, Callable, Collection, Dict, List, Optional, Union, cast
 
 from ..error import GraphQLError
 from ..language import (
@@ -17,7 +17,7 @@ from ..language import (
     VariableNode,
     print_ast,
 )
-from ..pyutils import inspect, print_path_list, FrozenList, Undefined
+from ..pyutils import inspect, print_path_list, Undefined
 from ..type import (
     GraphQLDirective,
     GraphQLField,
@@ -38,7 +38,7 @@ CoercedVariableValues = Union[List[GraphQLError], Dict[str, Any]]
 
 def get_variable_values(
     schema: GraphQLSchema,
-    var_def_nodes: FrozenList[VariableDefinitionNode],
+    var_def_nodes: Collection[VariableDefinitionNode],
     inputs: Dict[str, Any],
     max_errors: Optional[int] = None,
 ) -> CoercedVariableValues:
@@ -72,7 +72,7 @@ def get_variable_values(
 
 def coerce_variable_values(
     schema: GraphQLSchema,
-    var_def_nodes: FrozenList[VariableDefinitionNode],
+    var_def_nodes: Collection[VariableDefinitionNode],
     inputs: Dict[str, Any],
     on_error: Callable[[GraphQLError], None],
 ) -> Dict[str, Any]:
