@@ -4,9 +4,9 @@ from typing import NamedTuple
 __all__ = ["version", "version_info", "version_js", "version_info_js"]
 
 
-version = "3.1.6"
+version = "3.2.0"
 
-version_js = "15.5.1"
+version_js = "16.2.0"
 
 
 _re_version = re.compile(r"(\d+)\.(\d+)\.(\d+)(\D*)(\d*)")
@@ -40,7 +40,10 @@ class VersionInfo(NamedTuple):
         v = f"{self.major}.{self.minor}.{self.micro}"
         level = self.releaselevel
         if level and level != "final":
-            v = f"{v}{level[:1]}{self.serial}"
+            level = level[:1]
+            if level == "c":
+                level = "rc"
+            v = f"{v}{level}{self.serial}"
         return v
 
 
